@@ -774,7 +774,7 @@ void SimulateIso14443bTag(const uint8_t *pupi) {
     int cardSTATE = SIM_NOFIELD;
     int vHf = 0; // in mV
 
-    tosend_t *ts = get_tosend();
+    const tosend_t *ts = get_tosend();
 
     uint8_t *receivedCmd = BigBuf_calloc(MAX_FRAME_SIZE);
 
@@ -1566,7 +1566,7 @@ static void CodeIso14443bAsReader(const uint8_t *cmd, int len, bool framing) {
 *  Convenience function to encode, transmit and trace iso 14443b comms
 */
 static void CodeAndTransmit14443bAsReader(const uint8_t *cmd, int len, uint32_t *start_time, uint32_t *eof_time, bool framing) {
-    tosend_t *ts = get_tosend();
+    const tosend_t *ts = get_tosend();
     CodeIso14443bAsReader(cmd, len, framing);
     TransmitFor14443b_AsReader(start_time);
     if (g_trigger) LED_A_ON();
@@ -1582,7 +1582,7 @@ static void CodeAndTransmit14443bAsReader(const uint8_t *cmd, int len, uint32_t
 /* Sends an APDU to the tag
  * TODO: check CRC and preamble
  */
-int iso14443b_apdu(uint8_t const *msg, size_t msg_len, bool send_chaining, void *rxdata, uint16_t rxmaxlen, uint8_t *response_byte, uint16_t *reponselen) {
+int iso14443b_apdu(uint8_t const *msg, size_t msg_len, bool send_chaining, void *rxdata, uint16_t rxmaxlen, uint8_t *response_byte, uint16_t *responselen) {
 
     uint8_t real_cmd[msg_len + 4];
 
@@ -1693,8 +1693,8 @@ int iso14443b_apdu(uint8_t const *msg, size_t msg_len, bool send_chaining, void
         }
     }
 
-    if (reponselen) {
-        *reponselen = len;
+    if (responselen) {
+        *responselen = len;
     }
     return PM3_SUCCESS;
 }
