@@ -58,6 +58,40 @@ static const char *em4x69_annotation [] = {"Info", "UID", "Password", "Lock", "C
 
 static int CmdHelp(const char *Cmd);
 
+static int CmdEM4x05CloneHelp(const char *Cmd) {
+    CLIParserContext *ctx;
+    CLIParserInit(&ctx, "lf em 4x05 clonehelp",
+                  "Display a list of available commands for cloning specific techs on EM4305/4469 tags",
+                  "lf em 4x05 clonehelp"
+                 );
+    void *argtable[] = {
+        arg_param_begin,
+        arg_param_end
+    };
+    CLIExecWithReturn(ctx, Cmd, argtable, true);
+    CLIParserFree(ctx);
+    PrintAndLogEx(NORMAL, "For cloning specific techs on EM4305/4469 tags, see commands available in corresponding LF sub-menus, e.g.:");
+    PrintAndLogEx(NORMAL, _GREEN_("lf awid clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf destron clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf em 410x clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf fdxb clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf gallagher clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf hid clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf jablotron clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf keri clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf nedap clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf nexwatch clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf noralsy clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf pac clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf paradox clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf presco clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf pyramid clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf securakey clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf viking clone --em"));
+    PrintAndLogEx(NORMAL, _GREEN_("lf visa2000 clone --em"));
+    return PM3_SUCCESS;
+}
+
 // 1 = EM4x69
 // 2 = EM4x05
 static em_tech_type_t em_get_card_type(uint32_t config) {
@@ -141,7 +175,7 @@ static bool em4x05_download_samples(void) {
         return false;
     }
 
-    setGraphBuf(got, sizeof(got));
+    setGraphBuffer(got, sizeof(got));
     // set signal properties low/high/mean/amplitude and is_noise detection
     computeSignalProperties(got, sizeof(got));
     RepaintGraphWindow();
@@ -1716,9 +1750,9 @@ int CmdEM4x05Chk(const char *Cmd) {
         res = loadFileDICTIONARY_safe(filename, (void **) &keyBlock, 4, &keycount);
         if (res != PM3_SUCCESS || keycount == 0 || keyBlock == NULL) {
             PrintAndLogEx(WARNING, "no keys found in file");
-            if (keyBlock != NULL)
+            if (keyBlock != NULL) {
                 free(keyBlock);
-
+            }
             return PM3_ESOFT;
         }
 
@@ -2496,7 +2530,7 @@ int CmdEM4x05Sniff(const char *Cmd) {
 
 static int CmdEM4x05View(const char *Cmd) {
     CLIParserContext *ctx;
-    CLIParserInit(&ctx, "lf em ex05 view",
+    CLIParserInit(&ctx, "lf em 4x05 view",
                   "Print a EM4205/4305/4369/4469 dump file\n"
                   "note:\n"
                   "We don't track if password is known in current dump file formats.\n"
@@ -2552,7 +2586,7 @@ static int CmdEM4x05View(const char *Cmd) {
 static int CmdEM4x05Config(const char *Cmd) {
 
     CLIParserContext *ctx;
-    CLIParserInit(&ctx, "lf em ex05 config",
+    CLIParserInit(&ctx, "lf em 4x05 config",
                   "Create common configuration blocks",
                   "lf em 4x05 config"
                  );
@@ -2595,21 +2629,22 @@ static int CmdEM4x05Config(const char *Cmd) {
 }
 
 static command_t CommandTable[] = {
-    {"-----------", CmdHelp,          AlwaysAvailable, "----------------------- " _CYAN_("General") " -----------------------"},
-    {"help",        CmdHelp,          AlwaysAvailable, "This help"},
-    {"-----------", CmdHelp,          AlwaysAvailable, "----------------------- " _CYAN_("Operations") " -----------------------"},
-    {"brute",       CmdEM4x05Brute,   IfPm3Lf,         "Bruteforce password"},
-    {"chk",         CmdEM4x05Chk,     IfPm3Lf,         "Check passwords from dictionary"},
-    {"config",      CmdEM4x05Config,  AlwaysAvailable, "Create common configuration words"},
-    {"demod",       CmdEM4x05Demod,   AlwaysAvailable, "Demodulate a EM4x05/EM4x69 tag from the GraphBuffer"},
-    {"dump",        CmdEM4x05Dump,    IfPm3Lf,         "Dump EM4x05/EM4x69 tag"},
-    {"info",        CmdEM4x05Info,    IfPm3Lf,         "Tag information"},
-    {"read",        CmdEM4x05Read,    IfPm3Lf,         "Read word data from EM4x05/EM4x69"},
-    {"sniff",       CmdEM4x05Sniff,   AlwaysAvailable, "Attempt to recover em4x05 commands from sample buffer"},
-    {"unlock",      CmdEM4x05Unlock,  IfPm3Lf,         "Execute tear off against EM4x05/EM4x69"},
-    {"view",        CmdEM4x05View,    AlwaysAvailable, "Display content from tag dump file"},
-    {"wipe",        CmdEM4x05Wipe,    IfPm3Lf,         "Wipe EM4x05/EM4x69 tag"},
-    {"write",       CmdEM4x05Write,   IfPm3Lf,         "Write word data to EM4x05/EM4x69"},
+    {"-----------", CmdHelp,            AlwaysAvailable, "----------------------- " _CYAN_("General") " -----------------------"},
+    {"help",        CmdHelp,            AlwaysAvailable, "This help"},
+    {"-----------", CmdHelp,            AlwaysAvailable, "----------------------- " _CYAN_("Operations") " -----------------------"},
+    {"clonehelp",   CmdEM4x05CloneHelp, IfPm3Lf,         "Shows the available clone commands"},
+    {"brute",       CmdEM4x05Brute,     IfPm3Lf,         "Bruteforce password"},
+    {"chk",         CmdEM4x05Chk,       IfPm3Lf,         "Check passwords"},
+    {"config",      CmdEM4x05Config,    AlwaysAvailable, "Create common configuration words"},
+    {"demod",       CmdEM4x05Demod,     AlwaysAvailable, "Demodulate a EM4x05/EM4x69 tag from the GraphBuffer"},
+    {"dump",        CmdEM4x05Dump,      IfPm3Lf,         "Dump EM4x05/EM4x69 tag"},
+    {"info",        CmdEM4x05Info,      IfPm3Lf,         "Tag information"},
+    {"read",        CmdEM4x05Read,      IfPm3Lf,         "Read word data from EM4x05/EM4x69"},
+    {"sniff",       CmdEM4x05Sniff,     AlwaysAvailable, "Attempt to recover em4x05 commands from sample buffer"},
+    {"unlock",      CmdEM4x05Unlock,    IfPm3Lf,         "Execute tear off against EM4x05/EM4x69"},
+    {"view",        CmdEM4x05View,      AlwaysAvailable, "Display content from tag dump file"},
+    {"wipe",        CmdEM4x05Wipe,      IfPm3Lf,         "Wipe EM4x05/EM4x69 tag"},
+    {"write",       CmdEM4x05Write,     IfPm3Lf,         "Write word data to EM4x05/EM4x69"},
     {NULL, NULL, NULL, NULL}
 };
 
