@@ -262,16 +262,16 @@ static int sda_test_pk(bool verbose) {
 int exec_sda_test(bool verbose) {
     int ret = sda_test_raw(verbose);
     if (ret) {
-        PrintAndLogEx(WARNING, "SDA raw test: %s", _RED_("failed"));
+        PrintAndLogEx(WARNING, "SDA raw test ( %s )", _RED_("fa1l"));
         return ret;
     }
-    PrintAndLogEx(SUCCESS, "SDA raw test: %s", _GREEN_("passed"));
+    PrintAndLogEx(SUCCESS, "SDA raw test ( %s )", _GREEN_("ok"));
 
     ret = sda_test_pk(verbose);
     if (ret) {
-        PrintAndLogEx(WARNING, "SDA test pk: %s", _RED_("failed"));
+        PrintAndLogEx(WARNING, "SDA test pk ( %s )", _RED_("fail"));
         return ret;
     }
-    PrintAndLogEx(SUCCESS, "SDA test pk: %s", _GREEN_("passed"));
+    PrintAndLogEx(SUCCESS, "SDA test pk ( %s )", _GREEN_("ok"));
     return 0;
 }
