@@ -75,6 +75,15 @@ const static vocabulary_t vocabulary[] = {
     { 1, "analyse foo" },
     { 1, "analyse units" },
     { 1, "data help" },
+    { 1, "data clear" },
+    { 1, "data hide" },
+    { 1, "data load" },
+    { 1, "data num" },
+    { 1, "data plot" },
+    { 1, "data print" },
+    { 1, "data save" },
+    { 1, "data setdebugmode" },
+    { 1, "data xor" },
     { 1, "data biphaserawdecode" },
     { 1, "data detectclock" },
     { 1, "data fsktonrz" },
@@ -83,43 +92,35 @@ const static vocabulary_t vocabulary[] = {
     { 1, "data rawdemod" },
     { 1, "data askedgedetect" },
     { 1, "data autocorr" },
+    { 1, "data convertbitstream" },
+    { 1, "data cthreshold" },
     { 1, "data dirthreshold" },
     { 1, "data decimate" },
     { 1, "data envelope" },
-    { 1, "data undecimate" },
-    { 1, "data hide" },
+    { 1, "data grid" },
+    { 1, "data getbitstream" },
     { 1, "data hpf" },
     { 1, "data iir" },
-    { 1, "data grid" },
     { 1, "data ltrim" },
     { 1, "data mtrim" },
     { 1, "data norm" },
-    { 1, "data plot" },
-    { 1, "data cthreshold" },
     { 1, "data rtrim" },
     { 1, "data setgraphmarkers" },
     { 1, "data shiftgraphzero" },
     { 1, "data timescale" },
+    { 1, "data undecimate" },
     { 1, "data zerocrossings" },
-    { 1, "data convertbitstream" },
-    { 1, "data getbitstream" },
     { 1, "data asn1" },
     { 1, "data atr" },
-    { 1, "data bin2hex" },
     { 0, "data bitsamples" },
     { 1, "data bmap" },
-    { 1, "data clear" },
     { 1, "data crypto" },
     { 1, "data diff" },
     { 0, "data hexsamples" },
-    { 1, "data hex2bin" },
-    { 1, "data load" },
-    { 1, "data num" },
-    { 1, "data print" },
     { 0, "data samples" },
-    { 1, "data save" },
-    { 1, "data setdebugmode" },
-    { 0, "data tune" },
+    { 0, "data test_ss8" },
+    { 0, "data test_ss32" },
+    { 0, "data test_ss32s" },
     { 1, "emv help" },
     { 1, "emv list" },
     { 1, "emv test" },
@@ -166,11 +167,14 @@ const static vocabulary_t vocabulary[] = {
     { 0, "hf 14b raw" },
     { 0, "hf 14b rdbl" },
     { 0, "hf 14b reader" },
+    { 0, "hf 14b restore" },
     { 0, "hf 14b sim" },
     { 0, "hf 14b sniff" },
     { 0, "hf 14b wrbl" },
     { 1, "hf 14b view" },
     { 1, "hf 14b valid" },
+    { 0, "hf 14b calypso" },
+    { 0, "hf 14b mobib" },
     { 1, "hf 15 help" },
     { 1, "hf 15 list" },
     { 1, "hf 15 demod" },
@@ -415,19 +419,20 @@ const static vocabulary_t vocabulary[] = {
     { 1, "hf mfu pwdgen" },
     { 0, "hf mfu otptear" },
     { 0, "hf mfu cauth" },
+    { 0, "hf mfu setpwd" },
     { 0, "hf mfu dump" },
     { 0, "hf mfu info" },
     { 0, "hf mfu ndefread" },
     { 0, "hf mfu rdbl" },
     { 0, "hf mfu restore" },
-    { 1, "hf mfu view" },
-    { 0, "hf mfu wrbl" },
     { 0, "hf mfu tamper" },
+    { 1, "hf mfu view" },
+    { 0, "hf mfu wipe" },
+    { 0, "hf mfu wrbl" },
     { 0, "hf mfu eload" },
     { 0, "hf mfu esave" },
     { 0, "hf mfu eview" },
     { 0, "hf mfu sim" },
-    { 0, "hf mfu setpwd" },
     { 0, "hf mfu setuid" },
     { 0, "hf mfu amiibo" },
     { 1, "hf mfdes help" },
@@ -522,11 +527,15 @@ const static vocabulary_t vocabulary[] = {
     { 1, "hf xerox view" },
     { 0, "hf xerox rdbl" },
     { 1, "hw help" },
+    { 0, "hw detectreader" },
+    { 0, "hw status" },
+    { 0, "hw tearoff" },
+    { 1, "hw timeout" },
+    { 1, "hw version" },
     { 0, "hw break" },
     { 0, "hw bootloader" },
     { 1, "hw connect" },
     { 0, "hw dbg" },
-    { 0, "hw detectreader" },
     { 0, "hw fpgaoff" },
     { 0, "hw lcd" },
     { 0, "hw lcdreset" },
@@ -537,12 +546,8 @@ const static vocabulary_t vocabulary[] = {
     { 0, "hw sethfthresh" },
     { 0, "hw setmux" },
     { 0, "hw standalone" },
-    { 0, "hw status" },
-    { 0, "hw tearoff" },
     { 0, "hw tia" },
-    { 1, "hw timeout" },
     { 0, "hw tune" },
-    { 1, "hw version" },
     { 1, "lf help" },
     { 0, "lf config" },
     { 0, "lf cmdread" },
@@ -556,11 +561,11 @@ const static vocabulary_t vocabulary[] = {
     { 0, "lf sniff" },
     { 0, "lf tune" },
     { 1, "lf awid help" },
+    { 0, "lf awid brute" },
+    { 0, "lf awid clone" },
     { 1, "lf awid demod" },
     { 0, "lf awid reader" },
-    { 0, "lf awid clone" },
     { 0, "lf awid sim" },
-    { 0, "lf awid brute" },
     { 0, "lf awid watch" },
     { 1, "lf cotag help" },
     { 1, "lf cotag demod" },
@@ -580,6 +585,7 @@ const static vocabulary_t vocabulary[] = {
     { 0, "lf em 410x spoof" },
     { 0, "lf em 410x clone" },
     { 1, "lf em 4x05 help" },
+    { 0, "lf em 4x05 clonehelp" },
     { 0, "lf em 4x05 brute" },
     { 0, "lf em 4x05 chk" },
     { 1, "lf em 4x05 config" },
@@ -615,8 +621,11 @@ const static vocabulary_t vocabulary[] = {
     { 0, "lf em 4x70 write" },
     { 0, "lf em 4x70 unlock" },
     { 0, "lf em 4x70 auth" },
-    { 0, "lf em 4x70 writepin" },
-    { 0, "lf em 4x70 writekey" },
+    { 0, "lf em 4x70 setpin" },
+    { 0, "lf em 4x70 setkey" },
+    { 1, "lf em 4x70 calc" },
+    { 1, "lf em 4x70 recover" },
+    { 0, "lf em 4x70 autorecover" },
     { 1, "lf fdxb help" },
     { 1, "lf fdxb demod" },
     { 0, "lf fdxb reader" },
@@ -642,16 +651,21 @@ const static vocabulary_t vocabulary[] = {
     { 1, "lf hitag help" },
     { 1, "lf hitag list" },
     { 0, "lf hitag info" },
+    { 0, "lf hitag reader" },
+    { 1, "lf hitag test" },
     { 0, "lf hitag dump" },
     { 0, "lf hitag read" },
+    { 0, "lf hitag sniff" },
     { 1, "lf hitag view" },
     { 0, "lf hitag wrbl" },
-    { 0, "lf hitag sniff" },
-    { 0, "lf hitag cc" },
-    { 0, "lf hitag ta" },
     { 0, "lf hitag eload" },
     { 0, "lf hitag eview" },
     { 0, "lf hitag sim" },
+    { 0, "lf hitag cc" },
+    { 0, "lf hitag crack2" },
+    { 0, "lf hitag chk" },
+    { 1, "lf hitag lookup" },
+    { 0, "lf hitag ta" },
     { 1, "lf idteck help" },
     { 1, "lf idteck demod" },
     { 0, "lf idteck reader" },
